Crate stageleft_macro

Crate stageleft_macro 

Macros

q
Creates a quoted expression for Hydro.
quse_fn

Attribute Macros

entry
Defines an entrypoint for staged code, which will be available as a proc macro. The entrypoint must be a function that returns impl Quoted<T> for some type T.
export
Marks that a macro invocation creates one or more pub items. Must be invoked via #[stageleft::export(...)], do not do use.