Crate stageleft_macro
stageleft_
macro
0.13.2
All Items
Crate Items
Macros
Attribute Macros
Crate
stageleft_
macro
Macros

q
Creates a quoted expression for Hydro.
quse_fn
Attribute Macros

entry
Defines an entrypoint for staged code, which will be available as a proc macro. The entrypoint must be a function that returns
impl Quoted<T>
for some type
T
.
export
Marks that a macro invocation creates one or more
pub
items. Must be invoked via
#[stageleft::export(...)]
, do not do
use
.